Learn R Programming

DIME (version 1.3.0)

DIME-package: DIME (Differential Identification using Mixtures Ensemble)

Description

A robust differential identification method that considers an ensemble of finite mixture models combined with a local false discovery rate (fdr) for analyzing ChIP-seq data comparing two samples.
This package can also be used to identify differential in other high throughput data such as microarray, methylation etc.
After normalization, an Exponential-Normal(k) or a Uniform-Normal(k) mixture is fitted to the data. The (k)-normal component can represent either differential regions or non-differential regions depending on their location and spread. The exponential or uniform represent differentially sites. local (fdr) are computed from the fitted model. Unique features of the package:

  1. Using ensemble of mixture models allowing data to be accurately & efficiently represented. Then two-phase selection ensure the selection of the best overall model.

  2. This method can be used as a general program to fit a mixture of uniform-normal or uniform-k-normal or exponential-k-normal

Arguments

Author

Cenny Taslim [email protected], with contributions from Abbas Khalili [email protected], Dustin Potter [email protected], and Shili Lin [email protected]
Maintainer: Cenny Taslim [email protected] or Shili Lin [email protected]

Details

Package:DIME
Type:Package
Version:1.0
Date:2010-11-19
License:GPL-2
LazyLoad:yes

References

  • Khalili, A., Huang, T., and Lin, S. (2009). A robust unified approach to analyzing methylation and gene expression data. Computational Statistics and Data Analysis, 53(5), 1701-1710.

  • Dean, N. and Raftery, A. E. (2005). Normal uniform mixture differential gene expression detection for cDNA microarrays. BMC Bioinformatics, 6, 173.

  • Taslim, C., Wu, J., Yan, P., Singer, G., Parvin, J., Huang, T., Lin, S., and Huang, K. (2009). Comparative study on chip-seq data: normalization and binding pattern characterization. Bioinformatics, 25(18), 2334-2340.