Learn R Programming

DIME (version 1.3.1)

gng.plot.mix: Plot GNG Mixture Component Function

Description

Plot each estimated individual components of GNG mixture model fitted using gng.fit.

Usage

gng.plot.mix(obj, amplify = 1, resolution = 100, new.plot = TRUE, ...)

Arguments

obj

a list object returned by gng.fit function.

amplify

optional scaling factor for visualization purposes.

resolution

optional bandwidth used to estimate the density function. Higher number makes a smoother curve.

new.plot

optional logical variable on whether to create new plot.

...

additional graphical arguments to be passed to methods (see par).

Author

Cenny Taslim [email protected], with contributions from Abbas Khalili [email protected], Dustin Potter [email protected], and Shili Lin [email protected]

See Also

gng.plot.mix, gng.plot.comp, gng.plot.fit, gng.plot.qq, DIME.plot.fit, inudge.plot.fit.

Examples

Run this code
library(DIME)
# generate simulated datasets with underlying exponential-normal components
N1 <- 1500; N2 <- 500; K <- 4; rmu <- c(-2.25,1.50); rsigma <- c(1,1); 
rpi <- c(.05,.45,.45,.05); rbeta <- c(12,10);
set.seed(1234);
chr1 <- c(-rgamma(ceiling(rpi[1]*N1),shape = 1,scale = rbeta[1]), 
  rnorm(ceiling(rpi[2]*N1),rmu[1],rsigma[1]), 
  rnorm(ceiling(rpi[3]*N1),rmu[2],rsigma[2]), 
  rgamma(ceiling(rpi[4]*N1),shape = 1,scale = rbeta[2]));
chr2 <- c(-rgamma(ceiling(rpi[1]*N2),shape = 1,scale = rbeta[1]), 
  rnorm(ceiling(rpi[2]*N2),rmu[1],rsigma[1]), 
  rnorm(ceiling(rpi[3]*N2),rmu[2],rsigma[2]), 
  rgamma(ceiling(rpi[4]*N2),shape = 1,scale = rbeta[2])); 
chr3 <- c(-rgamma(ceiling(rpi[1]*N2),shape = 1,scale = rbeta[1]), 
  rnorm(ceiling(rpi[2]*N2),rmu[1],rsigma[1]), 
  rnorm(ceiling(rpi[3]*N2),rmu[2],rsigma[2]), 
  rgamma(ceiling(rpi[4]*N2),shape = 1,scale = rbeta[2]));
# analyzing only chromosome 1 and chromosome 3
data <- list(chr1,chr3);

# Fitting a GNG model only
bestGng <- gng.fit(data,K=2);

# Plot the estimated GNG model imposed on the histogram of the observed data
hist(unlist(data),freq=FALSE,breaks=100,xlim=c(-20,20))
gng.plot.mix(bestGng,resolution=1000,new.plot=FALSE,col="red");

Run the code above in your browser using DataLab